@@ -7,19 +7,21 @@ import plotly.graph_objects as go
 from math import ceil, floor
 from plotly.graph_objects import Figure
 from typing import Union
+from calendar import month_name
+from random import randint
 
 from ._to_dataframe import heatmap_dataframe
-from ._helper import discontinuous_to_continuous, rgb_to_hex
+from ._helper import discontinuous_to_continuous, rgb_to_hex, ColorSet, color_set
 
 from ladybug.datacollection import HourlyContinuousCollection, \
-    HourlyDiscontinuousCollection
+    HourlyDiscontinuousCollection, MonthlyCollection, DailyCollection
+from ladybug.color import Color
 from ladybug_pandas.series import Series
-from ladybug.color import Colorset
 
 
 def heatmap(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousCollection],
             min_range: float = None, max_range: float = None,
-            colorset: Colorset = Colorset.original()) -> Figure:
+            colorset: ColorSet = ColorSet.original) -> Figure:
     """Create a plotly heatmap figure from Ladybug Hourly data.
 
     Args:
@@ -29,7 +31,7 @@ def heatmap(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousCo
             will be calculated based on data. Defaults to None.
         max_range: The maximum value for the legend of the heatmap. If not set, value
             will be calculated based on data. Defaults to None.
-        colorset: A Ladybug Colorset object. Defaults to Original Ladybug Colorset.
+        colorset: A ColorSets object. Defaults to Original Ladybug Colorset.
 
     Returns:
         A plotly figure.
@@ -65,7 +67,7 @@ def heatmap(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousCo
             z=df[var],
             zmin=range_z[0],
             zmax=range_z[1],
-            colorscale=rgb_to_hex(colorset),
+            colorscale=[rgb_to_hex(color) for color in color_set[colorset.value]],
             customdata=np.stack((df["month_names"], df["day"]), axis=-1),
             hovertemplate=(
                 "<b>"
@@ -91,3 +93,63 @@ def heatmap(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousCo
     fig.update_yaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
 
     return fig
+
+
+def monthly_barchart(data: MonthlyCollection,
+                     chart_title: str = 'Unnamed',
+                     color: Color = Color(
+                         randint(0, 255), randint(0, 255), randint(0, 255))
+                     ) -> Figure:
+    """Create a plotly barchart figure from Ladybug monthly data.
+
+    Only continuous data is supported.
+
+    Args:
+        data: A Ladybug MonthlyCollection.
+        chart_title: A string to be used as the title of the plot. Defaults to 'Unnamed'.
+        color: A Ladybug color object. Defaults to a random color.
+
+    Returns:
+        A plotly figure.
+    """
+    assert isinstance(data, MonthlyCollection), 'Only continuous collections'\
+        ' of monthly data is'\
+        f' supported. Instead got {type(data)}'
+
+    # name and unit
+    var = data.header.data_type.name
+    var_unit = data.header.unit
+
+    fig_data = go.Bar(
+        x=[month[:3] for month in month_name[1:]],
+        y=[round(val, 2) for val in data.values],
+        text=[f'{round(val, 2)} {var_unit}' for val in data.values],
+        textposition='auto',
+        hovertemplate='<br>%{y} ' + var_unit + '<br>' + '<extra></extra>',
+        marker_color=rgb_to_hex(color)
+    )
+
+    fig = go.Figure(fig_data)
+    fig.update_xaxes(dtick="M1", tickformat="%b", ticklabelmode="period")
+    fig.update_yaxes(title_text=var + " (" + var_unit + ")")
+    fig.update_xaxes(title_text="Months of the year")
+
+    pio.templates.default = 'plotly_white'
+
+    fig.update_layout(
+        barmode='stack',
+        template='plotly_white',
+        margin=dict(l=20, r=20, t=33, b=20),
+        yaxis_nticks=13,
+        title={
+            'text': chart_title,
+            'y': 1,
+            'x': 0.5,
+            'xanchor': 'center',
+            'yanchor': 'top'}
+    )
+
+    fig.update_xaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
+    fig.update_yaxes(showline=True, linewidth=1, linecolor="black", mirror=True)
+
+    return fig
